# pypop [![Build Status](https://travis-ci.org/yuma-m/pypop.svg?branch=master)](https://travis-ci.org/yuma-m/pypop)
A python library to compose pop songs automatically.

## Installation

```bash
# Use python3.6 or above
$ python3 setup.py install
```

## Example

```bash
$ python3 example.py
```

## Supported Python Versions
- 3.6 and above
